@@ -13,7 +13,7 @@ local $^W = 1;
 # wish, but if you redistribute a modified version, please attach a note
 # listing the modifications you have made.
 
-$CGI::Fast::VERSION='2.07';
+$CGI::Fast::VERSION='2.08';
 
 use CGI;
 use FCGI;
@@ -125,6 +125,8 @@ CGI::Fast - CGI Interface for Fast CGI
         socket_perm  => 0777,
         listen_queue => 50;
 
+    use CGI qw/ :standard /;
+
     $COUNTER = 0;
 
     # optional, will default to STDOUT, STDIN, STDERR
@@ -134,15 +136,8 @@ CGI::Fast - CGI Interface for Fast CGI
         fcgi_error_file_handle  => IO::Handle->new,
     });
 
-    while (new CGI::Fast) {
-        print header;
-        print start_html("Fast CGI Rocks");
-        print
-        h1("Fast CGI Rocks"),
-        "Invocation number ",b($COUNTER++),
-            " PID ",b($$),".",
-        hr;
-        print end_html;
+    while ($q = CGI::Fast->new) {
+        process_request($q);
     }
 
 =head1 DESCRIPTION
@@ -173,7 +168,7 @@ A typical FastCGI script will look like this:
     #!perl
     use CGI::Fast;
     do_some_initialization();
-    while ($q = new CGI::Fast) {
+    while ($q = CGI::Fast->new) {
         process_request($q);
     }
 
@@ -189,7 +184,7 @@ scripts).
 CGI.pm's default CGI object mode also works.  Just modify the loop
 this way:
 
-    while (new CGI::Fast) {
+    while (CGI::Fast->new) {
         process_request();
     }
 
@@ -258,9 +253,11 @@ For example:
         listen_queue => "50"
     ;
 
+    use CGI qw/ :standard /;
+
     do_some_initialization();
 
-    while ($q = new CGI::Fast) {
+    while ($q = CGI::Fast->new) {
         process_request($q);
     }
 
@@ -268,16 +265,23 @@ For example:
 Or:
 
     use CGI::Fast;
+    use CGI qw/ :standard /;
 
     do_some_initialization();
 
     $ENV{FCGI_SOCKET_PATH} = "sputnik:8888";
     $ENV{FCGI_LISTEN_QUEUE} = 50;
 
-    while ($q = new CGI::Fast) {
+    while ($q = CGI::Fast->new) {
         process_request($q);
     }
 
+Note the importance of having use CGI after use CGI::Fast as this will
+prevent any CGI import pragmas being overwritten by CGI::Fast. You can
+use CGI::Fast as a drop in replacement like so:
+
+    use CGI::Fast qw/ :standard /
+
 =head1 FILE HANDLES
 
 FCGI defaults to using STDIN, STDOUT, and STDERR as its filehandles - this
@@ -292,7 +296,7 @@ IO::Handle:
         fcgi_error_file_handle  => IO::Handle->new,
     });
 
-    while (new CGI::Fast) {
+    while (CGI::Fast->new) {
         ..
     }
 
